==============================
aws_pcluster_bootstrap_helpers
==============================


.. image:: https://img.shields.io/pypi/v/aws_pcluster_bootstrap_helpers.svg
        :target: https://pypi.python.org/pypi/aws_pcluster_bootstrap_helpers

.. image:: https://img.shields.io/travis/dabble-of-devops-bioanalyze/aws_pcluster_bootstrap_helpers.svg
        :target: https://travis-ci.com/dabble-of-devops-bioanalyze/aws_pcluster_bootstrap_helpers

.. image:: https://readthedocs.org/projects/aws-pcluster-bootstrap-helpers/badge/?version=latest
        :target: https://aws-pcluster-bootstrap-helpers.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Helpers to bootstrap a AWS PCluster + SLURM + Custom AMIs


* Free software: Apache Software License 2.0
* Documentation: https://aws-pcluster-bootstrap-helpers.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
